==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/search/classes/TypeConverter.php <==
<?php
namespace Claromentis\Search;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_822680520327e9387ae2d5c065ea5" . "2e1" => base64_decode("YXJyYXlfZmxpcA" . "=="), "_a591754a8d" . "dcdbda9c80f" . "1db4d911e14" => base64_decode("aXNfbnVsb" . "A=="));
use Claromentis\Search\ItemType\Indexing as ITI;





class TypeConverter
{
    protected static $num_to_str = null;
    protected static $str_to_num = null;
    public static function NumToStr($_556b5f873a16cb1e6c433be7b84986c3)
    {
        self::Init();
        return self::$num_to_str[$_556b5f873a16cb1e6c433be7b84986c3];
    }
    public static function NumToArray($_2ecb78ad6faa71d796229d683651d70f)
    {
        self::Init();
        $_3f2b9f6497e9b07683841065b2802295 = array();
        foreach (self::$num_to_str as $_d10f5990572371234949e1098af64137 => $_34460bffd3af92da81e46ee15e9e66e3) {
            if ($_2ecb78ad6faa71d796229d683651d70f & $_d10f5990572371234949e1098af64137) {
                $_3f2b9f6497e9b07683841065b2802295[] = $_34460bffd3af92da81e46ee15e9e66e3;
            }
        }
        return $_3f2b9f6497e9b07683841065b2802295;
    }
    public static function ArrayToNum($_dd71aee3bbba3e5a00ce66010e5176a9)
    {
        self::Init();
        $_d10f5990572371234949e1098af64137 = 0;
        foreach ($_dd71aee3bbba3e5a00ce66010e5176a9 as $_15a860e9b319fc72828fc64a6868dbb2) {
            $_d10f5990572371234949e1098af64137 |= self::StrToNum($_15a860e9b319fc72828fc64a6868dbb2);
        }
        return $_d10f5990572371234949e1098af64137;
    }
    public static function StrToNum($_2a34a5c75490636081526ededde991c8)
    {
        self::Init();
        if (!isset(self::$str_to_num[$_2a34a5c75490636081526ededde991c8])) {
            return null;
        }
        return self::$str_to_num[$_2a34a5c75490636081526ededde991c8];
    }
    protected static function Init()
    {
        if (!$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_a591754a8ddcdbda9c80f1" . "db4d911e14"](self::$str_to_num)) {
            return;
        }
        self::$num_to_str = array(
            SEARCH_OBJ_TYPE_DOCUMENT => ITI\Document::TYPE_NAME,
            SEARCH_OBJ_TYPE_FOLDER => ITI\Folder::TYPE_NAME,
            SEARCH_OBJ_TYPE_PUB_PAGE => ITI\PublishPage::TYPE_NAME,
            SEARCH_OBJ_TYPE_FORUM => ITI\ForumMessage::TYPE_NAME,
            
            
            SEARCH_OBJ_TYPE_NEWS => ITI\News::TYPE_NAME,
            SEARCH_OBJ_TYPE_USER => ITI\User::TYPE_NAME,
            SEARCH_OBJ_TYPE_HD_ISSUE => ITI\ICIssue::TYPE_NAME,
        );
        self::$str_to_num = $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_822680520327e9387ae2d5c065ea5" . "2e1"](self::$num_to_str);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/search/classes/TypeConverter.php <==
<?php
namespace Claromentis\Search;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] ?: array()) + array("_a591754a8ddcdbda9c80f1db4d911" . "e14" => base64_decode("aXNfbn" . "VsbA=="), "_82268052" . "0327e9387" . "ae2d5c065" . "ea52e1" => base64_decode("YXJyYXlfZmx" . "pcA=="));
use Claromentis\Search\ItemType\Indexing as ITI;





class TypeConverter
{
    protected static $num_to_str = null;
    protected static $str_to_num = null;
    public static function NumToStr($_556b5f873a16cb1e6c433be7b84986c3)
    {
        self::Init();
        return self::$num_to_str[$_556b5f873a16cb1e6c433be7b84986c3];
    }
    public static function NumToArray($_2ecb78ad6faa71d796229d683651d70f)
    {
        self::Init();
        $_3f2b9f6497e9b07683841065b2802295 = array();
        foreach (self::$num_to_str as $_d10f5990572371234949e1098af64137 => $_34460bffd3af92da81e46ee15e9e66e3) {
            if ($_2ecb78ad6faa71d796229d683651d70f & $_d10f5990572371234949e1098af64137) {
                $_3f2b9f6497e9b07683841065b2802295[] = $_34460bffd3af92da81e46ee15e9e66e3;
            }
        }
        return $_3f2b9f6497e9b07683841065b2802295;
    }
    public static function ArrayToNum($_dd71aee3bbba3e5a00ce66010e5176a9)
    {
        self::Init();
        $_d10f5990572371234949e1098af64137 = 0;
        foreach ($_dd71aee3bbba3e5a00ce66010e5176a9 as $_15a860e9b319fc72828fc64a6868dbb2) {
            $_d10f5990572371234949e1098af64137 |= self::StrToNum($_15a860e9b319fc72828fc64a6868dbb2);
        }
        return $_d10f5990572371234949e1098af64137;
    }
    public static function StrToNum($_2a34a5c75490636081526ededde991c8)
    {
        self::Init();
        if (!isset(self::$str_to_num[$_2a34a5c75490636081526ededde991c8])) {
            return null;
        }
        return self::$str_to_num[$_2a34a5c75490636081526ededde991c8];
    }
    protected static function Init()
    {
        if (!$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_a591754a8ddc" . "dbda9c80f1db4" . "d911e14"](self::$str_to_num)) {
            return;
        }
        self::$num_to_str = array(
            SEARCH_OBJ_TYPE_DOCUMENT => ITI\Document::TYPE_NAME,
            SEARCH_OBJ_TYPE_FOLDER => ITI\Folder::TYPE_NAME,
            SEARCH_OBJ_TYPE_PUB_PAGE => ITI\PublishPage::TYPE_NAME,
            SEARCH_OBJ_TYPE_FORUM => ITI\ForumMessage::TYPE_NAME,
            
            
            SEARCH_OBJ_TYPE_NEWS => ITI\News::TYPE_NAME,
            SEARCH_OBJ_TYPE_USER => ITI\User::TYPE_NAME,
            SEARCH_OBJ_TYPE_HD_ISSUE => ITI\ICIssue::TYPE_NAME,
        );
        self::$str_to_num = $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_82268052" . "0327e9387" . "ae2d5c065" . "ea52e1"](self::$num_to_str);
    }
}
